      subroutine printmat ( mat, nxa, nya, sl1, sl2, sl3, sl4)
c ======================================================================
c
c        programmer     Jos van Kan
c
c       version 1.0    27-03-1997
c
c
c   copyright (c) 1997
c   all rights reserved. no part of this publication may be reproduced,
c   stored in a retrieval system ( e.g., in memory, disk, or core)
c   or be transmitted by anya means, electronic, mechanical, photocopy,
c   recording, or otherwise, without written permission from the
c   author.
c
c
c **********************************************************************
c
c                       DESCRIPTION
c
c   Matrix consisting of a 9-point stencil on a nxa * nya grid is printed
c   per ROW of the grid, one stencil per line. It is assumed that
c   the matrixa has dimension (nxa, nya, 9)
c **********************************************************************
c
c                       KEYWORDS
c
c   multi_grid
c **********************************************************************
c
c                       MODULES USED
c
      use mgpreset
c **********************************************************************
c
c                       INPUT / OUTPUT PARAMETERS
c
      implicit none
      integer sl1, sl2, sl3, sl4
      integer nxa, nya
      double precision
     + mat(1-sl1:nxa+sl2, 1-sl3:nya+sl4,9)

c     mat       i    The nxa x nya x 9 coefficient matrixa of the
c                    discrete Laplacian
c     nxa       i    Number of grid x points on this level
c     nya       i    Number of grid y points on this level
c     sl1       i    Slack variable, x lower bound
c     sl2       i    Slack variable, x upper bound
c     sl3       i    Slack variable, y lower bound
c     sl4       i    Slack variable, y upper bound
c **********************************************************************
c
c                       COMMON BLOCKS
c
c **********************************************************************
c
c                       LOCAL PARAMETERS
c
      integer ixa, iya

c     ixa        Counter to number of grid x points on this level
c     iya        Counter to number of grid y points on this level
c **********************************************************************
c
c                       SUBROUTINES CALLED
c
c **********************************************************************
c
c                       I/O
c
c **********************************************************************
c
c                       ERROR MESSAGES
c
c **********************************************************************
c
c                       PSEUDO CODE
c
c **********************************************************************
c
c                       DATA STATEMENTS
c
c ======================================================================
c
      write (*, *) 'Print mat output. Matrix printed rows first, one ',
     + 'stencil per line'
      write (*, '(2A)') '           LOWER                      CENTER',
     +   '                     UPPER'
      do iya = 1, nya
         do ixa = 1, nxa
           write (*, 100)
     + mat (ixa, iya, p00), mat (ixa, iya, p10), mat (ixa, iya, p20),
     + mat (ixa, iya, p01), mat (ixa, iya, p11), mat (ixa, iya, p21),
     + mat (ixa, iya, p02), mat (ixa, iya, p12), mat (ixa, iya, p22)
         end do
         write (*, '(1X)')
      end do
100   format (3f8.3, 3x, 3f8.3, 3x, 3f8.3)
      end
